# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

import base64

from odoo import SUPERUSER_ID, _, http
from odoo.exceptions import AccessError, MissingError
from odoo.http import Response, request
from odoo.tools import consteq

from odoo.addons.portal.controllers.portal import CustomerPortal


class AccAccountMain(CustomerPortal):
    @http.route(
        ["/invoice/<int:invoice_id>"],
        type="http",
        auth="public",
        website=True,
        method=["GET"],
        csrf=False,
        sitemap=False,
    )
    def print_invoice(self, invoice_id, access_token=None, report_type="pdf", **kw):
        try:
            invoice_sudo = self._document_check_access(
                "acc.account", invoice_id, access_token=access_token
            )
        except (AccessError, MissingError):
            raise AccessError(_("Vous n'êtes pas autorisé à accéder à ce document"))

        if report_type == "pdf":
            return self._show_report(
                model=invoice_sudo,
                report_type=report_type,
                report_ref="acc_account.acc_account_invoices",
                download=False,
            )
        else:
            return Response(
                _("Aucun document n'est disponible à cette URL."), status=404
            )

    @http.route(
        ["/contract/<int:contract_id>"],
        type="http",
        auth="public",
        website=True,
        csrf=False,
        sitemap=False,
    )
    def print_contract(self, contract_id, access_token=None, **kw):
        contract = request.env["acc.contract"].browse([contract_id])
        contract_sudo = contract.with_user(SUPERUSER_ID).exists()
        if not contract_sudo:
            return Response(
                _("Aucun document n'est disponible à cette URL."), status=404
            )
        if (
            not access_token
            or not contract_sudo.access_token
            or not consteq(contract_sudo.access_token, access_token)
        ):
            return Response(
                _("Aucun document n'est disponible à cette URL."), status=404
            )
        else:
            status, headers, content_base64 = (
                request.env["ir.http"]
                .sudo()
                .binary_content(
                    model="acc.contract",
                    id=contract_sudo.id,
                    field="document",
                    default_mimetype="application/pdf",
                    download=False,
                )
            )
            content = base64.b64decode(content_base64)
            headers = http.set_safe_image_headers(headers, content)
            response = request.make_response(content, headers)
            response.status_code = status

            return response
