# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class AccCounter(models.Model):
    _inherit = "acc.counter"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    acc_account_surplus_ids = fields.One2many(
        "acc.account",
        "acc_delivery_id",
        domain=[("is_account_buyer", "=", True)],
        string="Factures Surplus liées",
    )
    acc_account_delivery_ids = fields.One2many(
        "acc.account", "acc_delivery_id", string="Factures liées"
    )
    acc_account_injection_ids = fields.One2many(
        "acc.account",
        "acc_injection_id",
        domain=[("is_account_buyer", "=", False)],
        string="Factures liées",
    )
    acc_account_delivery_count = fields.Integer(
        compute="_compute_acc_account_count", string="Nombre de factures clients"
    )
    acc_account_injection_count = fields.Integer(
        compute="_compute_acc_account_count", string="Nombre de factures producteurs"
    )
    acc_account_surplus_count = fields.Integer(
        compute="_compute_acc_account_count",
        string="Nombre de factures surplus producteurs",
    )
    is_account_auto_activate = fields.Boolean(
        "Facturation de l’autoconsommation automatisée"
    )
    is_account_surplus_activate = fields.Boolean("Facturation du surplus automatisée")

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.depends("acc_account_delivery_ids", "acc_account_delivery_ids")
    def _compute_acc_account_count(self):
        for res in self:
            res.acc_account_delivery_count = self.env["acc.account"].search_count(
                [("acc_delivery_id", "=", res.id)]
            )
            res.acc_account_injection_count = self.env["acc.account"].search_count(
                [("acc_injection_id", "=", res.id), ("is_account_buyer", "=", False)]
            )
            res.acc_account_surplus_count = self.env["acc.account"].search_count(
                [("acc_injection_id", "=", res.id), ("is_account_buyer", "=", True)]
            )

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------
    def action_view_acc_injection_accounts(self):
        self.ensure_one()
        action = self.env["ir.actions.actions"]._for_xml_id(
            "acc_account.action_acc_account"
        )
        action["domain"] = [("acc_injection_id", "=", self.id)]
        return action

    def action_view_acc_delivery_accounts(self):
        self.ensure_one()
        action = self.env["ir.actions.actions"]._for_xml_id(
            "acc_account.action_acc_account"
        )
        action["domain"] = [("acc_delivery_id", "=", self.id)]
        return action

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
