# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).
from odoo import api, fields, models


class AccSalePriceWizard(models.TransientModel):
    _name = "acc.sale.price.wizard"
    _description = "Prix de vente wizard"

    def _default_operation_id(self):
        return self.env.context.get("active_id")

    acc_sale_price_ids = fields.Many2many(
        "acc.sale.price", default=lambda self: self._default_sale_price_ids()
    )
    start_date = fields.Date("Début de période", default=fields.Date.context_today)
    acc_operation_id = fields.Many2one("acc.operation", default=_default_operation_id)

    @api.onchange("start_date")
    def _onchange_start_date(self):
        if self.start_date:
            for price in self.acc_sale_price_ids:
                price.start_date = self.start_date

    def _default_sale_price_ids(self):
        inj_ids = self.env["acc.counter"].search(
            [
                ("is_injection", "=", True),
                ("acc_operation_id", "=", self.env.context.get("active_id")),
            ]
        )
        recs = self.env["acc.counter"].search(
            [
                ("is_delivery", "=", True),
                ("acc_operation_id", "=", self.env.context.get("active_id")),
            ]
        )

        return [
            (
                0,
                0,
                {
                    "acc_delivery_id": rec.id,
                    "acc_injection_id": inj.id,
                    "acc_operation_id": self.env.context.get("active_id"),
                },
            )
            # # if there isn't a demo line record for the user, create a new one
            # if not rec.acc_sale_price_ids.filtered(lambda x: x.acc_operation_id == op) else
            # # otherwise, return the line
            # (4, rec.acc_sale_price_ids.filtered(lambda x: x.acc_operation_id == usr)[0].id)
            for rec in recs
            for inj in inj_ids
        ]
